@@ -36,6 +36,7 @@
 #' @param window Use `FALSE` to suppress generation of the `OVER`
 #'   statement used for window functions. This is necessary when generating
 #'   SQL for a grouped summary.
+#' @param context Use to carry information for special translation cases. For example, MS SQL needs a different conversion for is.na() in WHERE vs. SELECT clauses.  Expects a list.
 #' @export
 #' @examples
 #' # Regular maths is translated in a very straightforward way
@@ -108,7 +109,8 @@ translate_sql_ <- function(dots,
                            vars_group = NULL,
                            vars_order = NULL,
                            vars_frame = NULL,
-                           window = TRUE) {
+                           window = TRUE,
+                           context = list()) {
 
   if (length(dots) == 0) {
     return(sql())
@@ -123,6 +125,11 @@ translate_sql_ <- function(dots,
   old_con <- set_current_con(con)
   on.exit(set_current_con(old_con), add = TRUE)
 
+  if (length(context) > 0) {
+    old_context <- set_current_context(context)
+    on.exit(set_current_context(context), add = TRUE)
+  }
+
   if (window) {
     old_group <- set_win_current_group(vars_group)
     on.exit(set_win_current_group(old_group), add = TRUE)
@@ -182,14 +189,20 @@ sql_overscope <- function(expr, variant, con, window = FALSE,
   new_overscope(symbol_env, top_env)
 }
 
+is_infix_base <- function(x) {
+  x %in% c("::", "$", "@", "^", "*", "/", "+", "-", ">", ">=", "<", "<=",
+    "==", "!=", "!", "&", "&&", "|", "||", "~", "<-", "<<-")
+}
+is_infix_user <- function(x) {
+  grepl("^%.*%$", x)
+}
+
 default_op <- function(x) {
   assert_that(is_string(x))
-  infix <- c("::", "$", "@", "^", "*", "/", "+", "-", ">", ">=", "<", "<=",
-    "==", "!=", "!", "&", "&&", "|", "||", "~", "<-", "<<-")
 
-  if (x %in% infix) {
+  if (is_infix_base(x)) {
     sql_infix(x)
-  } else if (grepl("^%.*%$", x)) {
+  } else if (is_infix_user(x)) {
     x <- substr(x, 2, nchar(x) - 1)
     sql_infix(x)
   } else {
